# web_2_album

Return photo list and caption (markdown format) from web.

## usage

```
import web_2_album
photo_filename_list, caption = web_2_album.get(url)
```

## how to install

`pip3 install web_2_album`